bayesianbandits.api.Agent
=========================

.. currentmodule:: bayesianbandits.api

.. autoclass:: Agent

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Agent.__init__
      ~Agent.add_arm
      ~Agent.arm
      ~Agent.decay
      ~Agent.pull
      ~Agent.remove_arm
      ~Agent.select_for_update
      ~Agent.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Agent.arm_to_update
      ~Agent.arms
      ~Agent.policy
      ~Agent.rng
   
   